echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v gi-inspect-typelib) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
[ ! -f /lib/libgudev-1.0.so ] && echo "Installing libgudev" && extension --install libgudev && echo "Finished libgudev"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v mbimcli) == "" ]] && echo "Installing libmbim" && extension --install libmbim && echo "Finished libmbim"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v qmicli) == "" ]]; then
	echo "libqmi" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "libqmi" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
